@@ -1,6 +1,10 @@
 from sybil import Sybil
 from sybil.parsers.doctest import  DocTestParser
-from sybil.parsers.codeblock import CodeBlockParser
+try:
+    from sybil.parsers.codeblock import PythonCodeBlockParser
+except ImportError:
+    # sybil < 3 has it under the old name
+    from sybil.parsers.codeblock import CodeBlockParser as PythonCodeBlockParser
 from sybil.parsers.capture import parse_captures
 
 from testfixtures import TempDirectory
@@ -18,7 +22,7 @@ def sybil_teardown(namespace):
 pytest_collect_file = Sybil(
     parsers=[
         DocTestParser(),
-        CodeBlockParser(),
+        PythonCodeBlockParser(),
         parse_captures,
         FileParser('tempdir'),
     ],
